from setuptools import find_packages, setup
setup(
    name='mihai_lib',
    version='0.0.1',
    author='Angelica Barbu',
    author_email='angibarbu@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='A nice library'
)
